# The gradient expansion formalism factory (GEFF)

This python package is designed to handle gauge-field production during cosmic inflation
using the gradient expansion formalism (GEF).

With this package, the user has access to built-in and ready-to-use models to determine the dynamical evolution during axion inflation. Furthermore, the GEFF package allows you to create your own versions
of inflationary models featuring gauge-field production, which can be solved using the GEF technique.

To install this pacakge use

```bash
pip install cosmo-geff
```

or use the `geff.yml` file to create a conda environment,

```bash
conda env create -f geff.yml
```

For more information on the GEFF, please see our (documentation).

If you use this package in your work, please cite (...).
